@@ -152,8 +152,10 @@ prepare_results.MCA <- function(obj) {
   ind <- ind %>% left_join(tmp, by = c("Name", "Type", "Axis"))
   
   ## Qualitative data for individuals plot color mapping
-  quali_data <- obj$call$X[,obj$call$quali] %>% 
-    bind_cols(obj$call$X[,obj$call$quali.sup])
+  quali_data <- obj$call$X[,obj$call$quali]
+  if (!is.null(obj$quali.sup)) {
+    quali_data <- quali_data %>% bind_cols(obj$call$X[,obj$call$quali.sup, drop = FALSE])
+  }
   quali_data$Name <- rownames(obj$call$X)
     
   
